#!/usr/bin/env python3
"""generate base64 image"""
import base64


class Base64Im:
    """generate base64 image"""
    filename = "raw_data_3D_detectors.png"
    image = ""
    header = "data:image/png;base64,"

    def set_filename(self, filename):
        """set filename"""
        self.filename = filename

    def convert(self, filename="raw_data_3D_detectors.png"):
        """convert image"""
        self.filename = filename
        with open(self.filename, "rb") as image_file:
            data = image_file.read()
            image_bytes = base64.b64encode(data)
            image_str = image_bytes.decode('UTF-8')
            self.image = self.header + image_str


def main():
    """main"""
    base = Base64Im()
    print(base.image[0:50])


if __name__ == '__main__':
    main()



#!/usr/bin/env python3
"""search scicat"""
import os
import json
import urllib

import requests

from scicat import api


def search(text, max_number_results):
    """search scicat"""
    fields = {'text': text}
    limit = {'limit': max_number_results, 'order': "creationTime:desc"}
    fields_encode = urllib.parse.quote(json.dumps(fields))
    limit_encode = urllib.parse.quote(json.dumps(limit))
    apix = api.Api()
    dataset_url = os.path.join(apix.api, "Datasets/anonymousquery?fields=") + \
        fields_encode+"&limits="+limit_encode
    response = requests.get(dataset_url).json()
    print(len(response), "result found!")
    return response


def main():
    """main"""
    search("v20", 1)


if __name__ == "__main__":
    main()



"""setup"""
import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
    name='scicat',
    version='1.1.2',
    author="Gareth Murphy",
    author_email="garethcmurphy@gmail.com",
    description="a scicat search package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/garethcmurphy/scicat_pkg",
    packages=['scicat'],
    install_requires=[
        "requests",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
